pub enum RequestError {
Request,
Stream,
Disconnected,
Timeout,
}Expand description
An error which occurred during the parsing of a request.
Variants
Request
The request could not be parsed due to invalid data.
Stream
The request could not be parsed due to an issue with the stream.
Disconnected
The request could not be parsed since the client disconnected.
Timeout
The request timed out.